@@ -37,8 +37,7 @@
 #include "yelp-util.h"
 #include "yelp-scrollkeeper.h"
 
-#define d(x) x
-#undef DEBUG_OUTPUT
+#define d(x)
 
 static void   yvh_init                      (YelpViewTOC      *html);
 static void   yvh_class_init                (YelpViewTOCClass *klass);
@@ -58,7 +57,7 @@ enum {
 static gint signals[LAST_SIGNAL] = { 0 };
 
 typedef struct {
-	char *title;
+	char  *title;
 	GList *seriesids;
 } YelpImportantDocsSection;
 
@@ -73,6 +72,95 @@ struct _YelpViewTOCPriv {
 	int           buffer_pos;
 };
 
+/* HTML generation stuff */
+#define BG_COLOR "#ffffff"
+#define BLOCK_BG_COLOR "#c1c1c1"
+#define HELP_IMAGE "file:///gnome/head/INSTALL/share/pixmaps/gnome-help.png"
+
+#define PAGE_HEADER "<html>\n \
+  <head>\n \
+    <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">\n \
+    <title>\n \
+      %s\n \
+    </title> \n \
+    <style type=\"text/css\">\n \
+      A:link { color: #00008b; font-size: 10 }\n \
+      A:visited { color: #00008b; font-size: 10}\n \
+      A:active { color: #00008b; font-size: 10}\n \
+      h1 { font-size: 25 }\n \
+      h2 { font-size: 15 }\n \
+      BODY { color: #000000; font-size: 10 }\n \
+    </style>\n \
+  </head>\n \
+  <body bgcolor=\"" BG_COLOR "\">"
+
+#define PAGE_START "<table cellpadding=\"0\" \
+			      border=\"0\" \
+ 			      align=\"center\" \
+			      cellspacing=\"10\" \
+			      width=\"100%\"> \
+			      <tr align=\"left\" \
+			          valign=\"top\" \
+			          bgcolor=\"" BG_COLOR "\"> \
+			      <td height=\"69\" \
+			          align=\"center\" \
+			          valign=\"center\" \
+			          bgcolor=\"" BLOCK_BG_COLOR "\" \
+			          colspan=\"2\"> \
+			        <h1> \
+			          %s \
+			        </h1> \
+			      </td> \
+			      </tr> \
+			      <tr>"
+
+#define PAGE_END "</tr></table>"
+
+#define COLUMN_LEFT_START "<td valign=\"top\" width=\"50%\"> \
+            <table cellpadding=\"0\" \
+                   border=\"0\"\
+		   align=\"left\" \
+		   cellspacing=\"0\" \
+		   width=\"100%\"> \
+              <tr> \
+	        <td>"
+#define COLUMN_RIGHT_START "<td valign=\"top\"> \
+			      <table cellpadding=\"0\" \
+			             border=\"0\" \
+			             align=\"right\" \
+			             cellspacing=\"0\" \
+			             width=\"100%\"><tr><td>"
+
+#define COLUMN_END " \
+		</td> \
+              </tr> \
+            </table> \
+          </td>"
+
+#define TOC_BLOCK_START " \
+		  <table cellpadding=\"5\" \
+		         border=\"0\" \
+			 align=\"left\" \
+			 cellspacing=\"0\" \
+			 width=\"100%\" \
+			 bgcolor=\"" BLOCK_BG_COLOR "\"> \
+		    <tr> \
+		      <td>"
+
+#define TOC_BLOCK_END " \
+		      </td> \
+		    </tr> \
+		  </table> "
+
+#define TOC_BLOCK_SEPARATOR " \
+                </td> \
+	      </tr> \
+              <tr> \
+                <td>&nbsp;</td> \
+              </tr> \
+	      <tr>\
+	        <td>"
+
 GType
 yelp_view_toc_get_type (void)
 {
@@ -176,9 +264,7 @@ yelp_view_toc_write (YelpViewTOC *view, char *data, int len)
 		len = strlen (data);
 	}
 
-#ifdef DEBUG_OUTPUT
-	g_print ("%.*s", len,data);
-#endif
+	d(g_print ("%.*s", len,data));
 
 	while (len > 0) {
 		chunk_size = MIN (BUFFER_SIZE - priv->buffer_pos, len);
@@ -189,55 +275,29 @@ yelp_view_toc_write (YelpViewTOC *view, char *data, int len)
 		data += chunk_size;
 
 		if (priv->buffer_pos == BUFFER_SIZE) {
-			html_document_write_stream (priv->doc, priv->buffer, BUFFER_SIZE);
+			html_document_write_stream (priv->doc, 
+						    priv->buffer, 
+						    BUFFER_SIZE);
 			priv->buffer_pos = 0;
 		}
-		
 	}
 }
 
 static void
 yelp_view_toc_printf (YelpViewTOC *view, char *format, ...)
 {
-  va_list args;
-  gchar *string;
-  
-  g_return_if_fail (format != NULL);
-  
-  va_start (args, format);
-  string = g_strdup_vprintf (format, args);
-  va_end (args);
-
-  yelp_view_toc_write (view, string, -1);
-  
-  g_free (string);
-}
-
-static void
-yelp_view_toc_write_header (YelpViewTOC *view, char *title)
-{
-	char *header="\n"
-"<html>\n"
-"  <head>\n"
-"    <title>\n"
-"      %s\n"
-"    </title> \n"
-"    <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">\n"
-"    <style type=\"text/css\">\n"
-"      A:link { color: #00008b }\n"
-"      A:visited { color: #00008b }\n"
-"      A:active { color: #00008b }\n"
-"      BODY { color: #00008b }\n"
-"    </style>\n"
-"  </head>\n"
-"  <body bgcolor=\"#ffffff\">";
-	char *s;
-
-	s = g_strdup_printf (header, title);
-
-	yelp_view_toc_write (view, s, -1);
-
-	g_free (s);
+	va_list  args;
+	gchar   *string;
+	
+	g_return_if_fail (format != NULL);
+	
+	va_start (args, format);
+	string = g_strdup_vprintf (format, args);
+	va_end (args);
+	
+	yelp_view_toc_write (view, string, -1);
+	
+	g_free (string);
 }
 
 static void
@@ -256,27 +316,19 @@ yelp_view_toc_start (YelpViewTOC *view)
 	YelpViewTOCPriv *priv;
 	GNode           *node;
 	YelpSection     *section;
-	gchar           *table_start = "\n"
-"    <center>\n"
-"      <table cellspacing=\"20\" width=\"100%\">\n"
-"        <tr>\n";
-	gchar           *table_end = "\n"
-"      </tr>\n"
-"    </table>\n"
-"   </center>\n";
 	char            *seriesid;
 	GNode           *root;
 	char            *path;
 	GList           *sections, *seriesids;
-	gchar           *other_docs_string = _("Other Documents");
+	gchar           *page_title = _("Help Contents");
+	gchar           *section_gnome = _("GNOME - Desktop");
+	gchar           *section_additional = _("Additional documents");
 	gchar           *man_string = _("Manual pages");
 	gchar           *info_string = _("Info pages");
-	gchar           *installed_string = _("Installed documents");
 	YelpImportantDocsSection *important_section;
 	gboolean         important_doc_installed = FALSE;
-	gboolean         man_installed = FALSE;
-	gboolean         info_installed = FALSE;
-      
+	gboolean         left_column_started = FALSE;
+	
 	priv = view->priv;
 
 	if (!g_node_first_child (priv->doc_tree)) {
@@ -285,14 +337,14 @@ yelp_view_toc_start (YelpViewTOC *view)
 	
 	yelp_view_toc_open (view);
 	
-	yelp_view_toc_write_header (view, _("Start page"));
+	yelp_view_toc_printf (view, PAGE_HEADER, page_title);
 	
-	yelp_view_toc_write (view, table_start, -1);
-
 	yelp_view_toc_printf (view, 
-			      "<td valign=\"top\">\n");
-
+			      PAGE_START,
+			      page_title);
+	
 	sections = priv->important_sections;
+	
 	while (sections != NULL) {
 		important_section = sections->data;
 
@@ -312,9 +364,16 @@ yelp_view_toc_start (YelpViewTOC *view)
 		}
 		
  		if (important_doc_installed) {
+			if (!left_column_started) {
+				yelp_view_toc_printf (view, 
+						      COLUMN_LEFT_START);
+				left_column_started = TRUE;
+			}
+			
 			yelp_view_toc_printf (view, 
-					      "<h2>%s</h2>\n"
-					      "<ul>\n", 
+					      TOC_BLOCK_SEPARATOR
+					      TOC_BLOCK_START 
+					      "<h2>%s</h2>",
 					      important_section->title);
 		}
 		
@@ -328,31 +387,45 @@ yelp_view_toc_start (YelpViewTOC *view)
 			if (node) {
 				section = node->data;
 				yelp_view_toc_printf (view, 
-						      "<li><a href=\"%s\">%s</a>\n",
+						      "<a href=\"%s\">%s</a>\n",
 						      section->uri, section->name);
 			}
+
 			seriesids = seriesids->next;
 		}
 
-		yelp_view_toc_printf (view, "</ul>\n");
+		if (important_doc_installed) {
+			yelp_view_toc_printf (view, 
+					      TOC_BLOCK_END);
+			if (sections->next) {
+				yelp_view_toc_printf (view, 
+						      TOC_BLOCK_SEPARATOR);
+			}
+		}
 		
 		sections = sections->next;
+		important_doc_installed = FALSE;
+	}
+
+	if (left_column_started) {
+		yelp_view_toc_printf (view, COLUMN_END);
 	}
 	
-			      
-	yelp_view_toc_write (view, 
-			     "</ul>\n"
-			     "</td>\n", -1);
-
-
-
 	yelp_view_toc_printf (view, 
-			     "<td valign=\"top\">\n"
-			     "<h2>%s</h2>\n", installed_string);
+			      COLUMN_RIGHT_START);
 
 	root = yelp_util_find_toplevel (priv->doc_tree, "scrollkeeper");
 	node = g_node_first_child (root);
 
+	yelp_view_toc_printf (view,
+			      TOC_BLOCK_SEPARATOR
+			      TOC_BLOCK_START
+			      "<h2>%s</h2>\n",
+			      section_gnome);
+			      
+	root = yelp_util_find_node_from_name (priv->doc_tree, "GNOME");
+	node = g_node_first_child (root);
+
 	while (node) {
 		section = YELP_SECTION (node->data);
 		path = yelp_util_node_to_string_path (node);
@@ -364,37 +437,48 @@ yelp_view_toc_start (YelpViewTOC *view)
 		node = g_node_next_sibling (node);
 	}
 
-	if (yelp_util_find_toplevel (priv->doc_tree, "man")) {
-		man_installed = TRUE;
-	}
-	
-	if (yelp_util_find_toplevel (priv->doc_tree, "info")) {
-		info_installed = TRUE;
-	}
-	
-	
-	if (man_installed || info_installed) {
-		yelp_view_toc_printf (view, "<h2>%s</h2>\n", 
-				      other_docs_string);
-		
-		if (man_installed) {
+	yelp_view_toc_printf (view,
+			      TOC_BLOCK_END);
+
+	yelp_view_toc_printf (view,
+			      TOC_BLOCK_SEPARATOR
+			      TOC_BLOCK_START
+			      "<h2>%s</h2>\n",
+			      section_additional);
+
+	root = yelp_util_find_toplevel (priv->doc_tree, "scrollkeeper");
+	node = g_node_first_child (root);
+
+	while (node) {
+		section = YELP_SECTION (node->data);
+		if (strcmp (section->name, "GNOME")) {
+			path = yelp_util_node_to_string_path (node);
 			yelp_view_toc_printf (view, 
-					      "<a href=\"toc:man\">%s</a><br>\n",
-					      man_string);
-		}
-		
-		if (info_installed) {
-			yelp_view_toc_printf (view,
-					      "<a href=\"toc:info\">%s</a><br>\n",
-					      info_string);
+					      "<a href=\"toc:scrollkeeper/%s\">%s</a><br>\n", 
+					      path, section->name);
+			g_free (path);
+			
 		}
+		node = g_node_next_sibling (node);
 	}
+
+	if (yelp_util_find_toplevel (priv->doc_tree, "man")) {
+		yelp_view_toc_printf (view,
+				      "<a href=\"toc:man\">%s</a><br>\n",
+				      man_string);
+	}
+		
+	if (yelp_util_find_toplevel (priv->doc_tree, "info")) {
+		yelp_view_toc_printf (view,
+				      "<a href=\"toc:info\">%s</a><br>\n",
+				      info_string);
+	}
+
+	yelp_view_toc_printf (view,
+			      TOC_BLOCK_END
+			      COLUMN_END 
+			      PAGE_END);
 	
-	yelp_view_toc_write (view, 
-			     "</td>\n", -1);
-
-	yelp_view_toc_write (view, table_end, -1);
-
 	yelp_view_toc_write_footer (view);
 
 	yelp_view_toc_close (view);
@@ -432,11 +516,14 @@ static void
 yelp_view_toc_man_emit (YelpViewTOC *view, GNode *first)
 {
 	YelpViewTOCPriv *priv;
-	GNode *node, *child;
-	YelpSection *section;
-	gboolean got_a_leaf;
-	char *path, *url;
-	int i;
+	GNode           *node, *child;
+	YelpSection     *section;
+	gboolean         got_a_leaf;
+	char            *path, *url;
+	int              i;
+	gboolean         sub_started = FALSE;
+	gchar           *str_docs = _("Documents");
+	gchar           *str_subcats = _("Categories");
 
 	priv = view->priv;
 
@@ -444,22 +531,40 @@ yelp_view_toc_man_emit (YelpViewTOC *view, GNode *first)
 	node = first;
 	do {
 		if (node->children != NULL) {
+			if (!sub_started) {
+				yelp_view_toc_printf (view, TOC_BLOCK_START);
+				yelp_view_toc_printf (view, "<h3>%s</h3>", 
+						      str_subcats);
+				
+				sub_started = TRUE;
+			}
+			
 			child = node->children;
 			
 			section = node->data;
 
 			path = yelp_util_node_to_string_path (node);
-			yelp_view_toc_printf (view, "<h2><a href=\"toc:man/%s\">%s</a></h2>\n", path, section->name);
+			yelp_view_toc_printf (view, "<a href=\"toc:man/%s\">%s</a><br>\n", path, section->name);
 			g_free (path);
 		} else {
 			got_a_leaf = TRUE;
 		}
 	} while ((node = node->next) != NULL);
 
+	if (sub_started) {
+		yelp_view_toc_printf (view, TOC_BLOCK_END);
+		yelp_view_toc_printf (view, TOC_BLOCK_SEPARATOR);
+	}
 
 	if (got_a_leaf) {
+		yelp_view_toc_printf (view,  TOC_BLOCK_START);
+		yelp_view_toc_printf (view, "<h3>%s</h3>",
+				      str_docs);
+
+		yelp_view_toc_write (view, "</td></tr><tr><td>", -1);
+		
 		yelp_view_toc_write (view,
-				     "<table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%%\"><tbody>\n",
+				     "<table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%%\">\n",
 				     -1);
 
 		i = 0;
@@ -489,7 +594,9 @@ yelp_view_toc_man_emit (YelpViewTOC *view, GNode *first)
 		} while ((node = node->next) != NULL);
 		
 		yelp_view_toc_write (view, "</tr>\n", -1);
-		yelp_view_toc_write (view, "</tbody></table>\n", -1);
+		yelp_view_toc_write (view, "</table>\n", -1);
+
+		yelp_view_toc_printf (view, TOC_BLOCK_END);
 	}
 }
 
@@ -500,7 +607,7 @@ yelp_view_toc_man_2 (YelpViewTOC *view,
 	GNode *first;
 	gchar *name;
 	gchar *string = _("Manual pages");
-	
+
 	if (root->children == NULL) {
 		return;
 	}
@@ -509,15 +616,42 @@ yelp_view_toc_man_2 (YelpViewTOC *view,
 
 	yelp_view_toc_open (view);
 	
-	yelp_view_toc_write_header (view, string);
+	yelp_view_toc_printf (view, PAGE_HEADER, string);
 		
 	name = yelp_view_toc_full_path_name (view, root);
-	
-	yelp_view_toc_printf (view, "<h1><a href=\"toc:man\">%s</a>: '%s'</h1>\n", string, name);
+
+	yelp_view_toc_printf (view, 
+			      "<table cellpadding=\"0\""
+			      "border=\"0\""
+			      "align=\"center\""
+			      "cellspacing=\"10\""
+			      "width=\"100%\">"
+			      "<tr align=\"left\""
+			      "    valign=\"top\""
+			      "    bgcolor=\"" BG_COLOR "\">"
+			      "<td height=\"69\""
+			      "    align=\"center\""
+			      "    valign=\"center\""
+			      "    bgcolor=\"" BLOCK_BG_COLOR "\""
+			      "    colspan=\"2\">"
+			      "  <h2>"
+			      "    %s/%s"
+			      "  </h2>"
+			      "</td>"
+			      "</tr>"
+			      "<tr>",
+			      string, name);
+
 	g_free (name);
 
+	yelp_view_toc_printf (view, COLUMN_RIGHT_START);
+
 	yelp_view_toc_man_emit (view, first);
 		
+	yelp_view_toc_printf (view, 
+			      COLUMN_END
+			      PAGE_END);
+
 	yelp_view_toc_write_footer (view);
 	yelp_view_toc_close (view);
 }
@@ -530,7 +664,8 @@ yelp_view_toc_man_1 (YelpViewTOC *view)
 	YelpSection     *section;
 	char            *path;
 	gchar           *string = _("Manual Pages");
-	
+	gchar           *str_subcats = _("Categories");
+
 	priv = view->priv;
 
 	root = yelp_util_find_toplevel (priv->doc_tree, "man");
@@ -548,23 +683,37 @@ yelp_view_toc_man_1 (YelpViewTOC *view)
 
 	yelp_view_toc_open (view);
 	
-	yelp_view_toc_write_header (view, string);
-	
-	yelp_view_toc_printf (view, "<h1>%s</h1>\n", string);
-	
+	yelp_view_toc_printf (view, PAGE_HEADER, string);
+
+	yelp_view_toc_printf (view, 
+			      PAGE_START, 
+			      string);
+
+	yelp_view_toc_printf (view,
+			      COLUMN_RIGHT_START
+			      TOC_BLOCK_START 
+			      "<h2>%s</h2>", 
+			      str_subcats);
+
 	do {
 		child = g_node_first_child (node);
 		
 		if (child) {
 			section = YELP_SECTION (node->data);
 			path = yelp_util_node_to_string_path (node);
+
 			yelp_view_toc_printf (view, 
 					      "<a href=\"toc:man/%s\">%s</a><br>\n", 
 					      path, section->name);
 			g_free (path);
 		}
 	} while ((node = g_node_next_sibling (node)));
-		
+
+	yelp_view_toc_printf (view, 
+			      TOC_BLOCK_END
+			      COLUMN_END
+			      PAGE_END);
+
 	yelp_view_toc_write_footer (view);
 	yelp_view_toc_close (view);
 }
@@ -577,7 +726,8 @@ yelp_view_toc_info (YelpViewTOC *view)
 	YelpSection     *section;
 	char            *url;
 	gchar           *string = _("Info pages");
-	
+	gchar           *str_docs = _("Documents");
+
 	priv = view->priv;
 
 	root = yelp_util_find_toplevel (priv->doc_tree, "info");
@@ -595,10 +745,14 @@ yelp_view_toc_info (YelpViewTOC *view)
 
 	yelp_view_toc_open (view);
 	
-	yelp_view_toc_write_header (view, _("Info pages"));
-	
-	yelp_view_toc_printf (view, "<h1>%s</h1>\n", string);
-	
+	yelp_view_toc_printf (view, PAGE_HEADER, string);
+
+	yelp_view_toc_printf (view, PAGE_START, string);
+	yelp_view_toc_printf (view, COLUMN_RIGHT_START);
+	yelp_view_toc_printf (view, TOC_BLOCK_START);
+
+	yelp_view_toc_printf (view, "<h2>%s</h2>", str_docs);
+
 	do {
 		section = YELP_SECTION (node->data);
 		url = yelp_util_compose_path_url (root, section->uri);
@@ -608,6 +762,11 @@ yelp_view_toc_info (YelpViewTOC *view)
 		g_free  (url);
 	} while ((node = g_node_next_sibling (node)));
 		
+	yelp_view_toc_printf (view, 
+			      TOC_BLOCK_END
+			      COLUMN_END
+			      PAGE_END);
+
 	yelp_view_toc_write_footer (view);
 	yelp_view_toc_close (view);
 }
@@ -615,12 +774,12 @@ yelp_view_toc_info (YelpViewTOC *view)
 static void
 yelp_view_read_important_docs (YelpViewTOC *view)
 {
-	xmlDocPtr doc;
-	xmlNodePtr node;
-	xmlNodePtr child;
-	xmlNodePtr section;
-	xmlNodePtr title;
-	xmlChar *prop;
+	xmlDocPtr   doc;
+	xmlNodePtr  node;
+	xmlNodePtr  child;
+	xmlNodePtr  section;
+	xmlNodePtr  title;
+	xmlChar    *prop;
 	YelpImportantDocsSection *important_section;
 	
 	doc = xmlParseFile (DATADIR "/yelp/important_docs.xml");
@@ -697,8 +856,10 @@ yelp_view_toc_scrollkeeper (YelpViewTOC *view,
 	gboolean         got_a_leaf;
 	char            *path;
 	gchar           *name;
-	gchar           *string = _("Scrollkeeper docs for category");
-
+	gboolean         sub_started = FALSE;
+	gchar           *str_docs = _("Documents");
+	gchar           *str_subcats = _("Categories");
+		
 	priv = view->priv;
 	
 	if (root->children == NULL) {
@@ -707,52 +868,75 @@ yelp_view_toc_scrollkeeper (YelpViewTOC *view,
 	
 	yelp_view_toc_open (view);
 	
-	yelp_view_toc_write_header (view, "Scrollkeeper");
-		
 	name = yelp_view_toc_full_path_name (view, root);
-	yelp_view_toc_printf (view, "<h1>%s '%s'</h1>\n", string, name);
+
+	yelp_view_toc_printf (view, PAGE_HEADER, name);
+
+	yelp_view_toc_printf (view, PAGE_START, name);
+	
 	g_free (name);
 
+	yelp_view_toc_printf (view, COLUMN_RIGHT_START);
+
 	got_a_leaf = FALSE;
 	node = root->children;
-	while (node != NULL) {
+
+/* 	yelp_view_toc_printf (view, TOC_BLOCK_START); */
+
+	for (node = root->children; node; node = node->next) {
+		
 		if (node->children != NULL) {
+			if (!sub_started) {
+				yelp_view_toc_printf (view, TOC_BLOCK_START);
+				yelp_view_toc_printf (view, "<h2>%s</h2>", 
+						      str_subcats);
+						      
+				sub_started = TRUE;
+			}
+			
 			child = node->children;
 			
 			section = node->data;
 
 			path = yelp_util_node_to_string_path (node);
-			yelp_view_toc_printf (view, "<h2><a href=\"toc:scrollkeeper/%s\">%s</a></h2>\n", path, section->name);
+			yelp_view_toc_printf (view, "<a href=\"toc:scrollkeeper/%s\">%s</a><br>\n", path, section->name);
 			g_free (path);
 		} else {
 			got_a_leaf = TRUE;
 		}
-		node = node->next;
 	}
 
+	if (sub_started) {
+		yelp_view_toc_printf (view, TOC_BLOCK_END);
+	}
+
+/* 	yelp_view_toc_printf (view, TOC_BLOCK_END); */
 
 	if (got_a_leaf) {
-		yelp_view_toc_write (view, "<ul>\n", -1);
+		yelp_view_toc_printf (view, TOC_BLOCK_START);
+		yelp_view_toc_printf (view, "<h2>%s</h2>", str_docs);
+		
+/* 		yelp_view_toc_write (view, "<ul>\n", -1); */
 
-		node = root->children;
-		while (node != NULL) {
+		for (node = root->children; node; node = node->next) {
 			if (node->children == NULL) {
 				YelpSection *section;
 			
 				section = node->data;
-				yelp_view_toc_printf (view, "<li><a href=\"%s\">%s</a>\n", section->uri, section->name);
+				yelp_view_toc_printf (view, "<a href=\"%s\">%s</a><br>\n", section->uri, section->name);
 			}
-			node = node->next;
 		}
-		
-		yelp_view_toc_write (view, "</ul>\n", -1);
+
+		yelp_view_toc_printf (view, TOC_BLOCK_END);
 	}
-		
+
+	yelp_view_toc_printf (view, 
+			      COLUMN_END
+			      PAGE_END);
 	yelp_view_toc_write_footer (view);
 	yelp_view_toc_close (view);
 }
 
-
 void
 yelp_view_toc_open_url (YelpViewTOC *view, const char *url)
 {
@@ -794,7 +978,7 @@ yelp_view_toc_open_url (YelpViewTOC *view, const char *url)
 		if (path_string[0] == '/') {
 			/* Calculate where it should go */
 			path_string++;
-
+			
 			node = yelp_util_string_path_to_node  (path_string,
 							       view->priv->doc_tree);
 			if (node) {
@@ -806,4 +990,7 @@ yelp_view_toc_open_url (YelpViewTOC *view, const char *url)
 	} else {
 		g_warning ("Unknown toc type %s\n", url);
 	}
+
+ 	gtk_adjustment_set_value (
+ 		gtk_layout_get_vadjustment (GTK_LAYOUT (view)), 0);
 }
